import keras
import re
import string
import tensorflow
import numpy as np
from tensorflow.keras.preprocessing.sequence import pad_sequences

from keras.layers import *
from keras.models import *
from keras import backend as K

from keras_contrib.layers.crf import CRF, crf_loss, crf_viterbi_accuracy
from keras_contrib import losses

from attention import attention

import configparser
import h5py

# file = 'config.ini'
# config = configparser.ConfigParser()
# config.read(file)
# pos_h5_filepath = config['PATHS']['pos_h5_filepath']

# with h5py.File(pos_h5_filepath, 'r') as f:
#     model = f['model'][()]
    
# model2 = h5py.File(pos_h5_filepath, 'r')


# LOAD POS TAGGER MODEL
def get_POS_TAGGER_model():
    
    file = 'config.ini'
    config = configparser.ConfigParser()
    config.read(file)
    pos_h5_filepath = config['PATHS']['pos_h5_filepath']
    
    modelx = h5py.File(pos_h5_filepath, 'r')
    
    custom_objects = {'attention': attention}

    model2 = keras.models.load_model(modelx, custom_objects={'attention': attention, "CRF": CRF, 'crf_loss': crf_loss,'crf_viterbi_accuracy': crf_viterbi_accuracy}, compile=True)
    model2.compile(optimizer=tf.optimizers.Adam(lr=0.008), loss=losses.crf_loss, metrics=[tf.keras.metrics.Recall(),tf.keras.metrics.AUC(),tf.keras.metrics.Precision(),'accuracy'])
    model2.summary()
    
    return model2

get_POS_TAGGER_model()


import keras
import re
import string
import tensorflow
import numpy as np
from tensorflow.keras.preprocessing.sequence import pad_sequences

from keras.layers import *
from keras.models import *
from keras import backend as K

from keras_contrib.layers.crf import CRF, crf_loss, crf_viterbi_accuracy
from keras_contrib import losses

import pickle
from attention import attention



with open("models/vocab_model2.pkl", "rb") as f:
        vocab_model = pickle.load(f)


def NER_TAGGER_MODEL(test_samples):
    # Register the custom layer
    custom_objects = {'attention': attention}

    model2 = keras.models.load_model('models/NER_WORD(1).h5', custom_objects={'attention': attention, "CRF": CRF, 'crf_loss': crf_loss,'crf_viterbi_accuracy': crf_viterbi_accuracy}, compile=True)
    model2.compile(optimizer=tf.optimizers.Adam(lr=0.008), loss=losses.crf_loss, metrics=[tf.keras.metrics.Recall(),tf.keras.metrics.AUC(),tf.keras.metrics.Precision(),'accuracy'])
    # model2.summary()

    test_samples_X = []
    for s in test_samples:
        s_int = []
        for w in s:
            try:
                s_int.append(vocab_model[w.lower()])
            except KeyError:
                s_int.append(vocab_model['<_UNK_>'])
        test_samples_X.append(s_int)
    
    test_samples_X = pad_sequences(test_samples_X, maxlen=70, padding='post')

    predictions = model2.predict(test_samples_X)
    
    return predictions
    
    
def logits_to_tokens(sequences, index):
    token_sequences = []
    for categorical_sequence in sequences:
        token_sequence = []
        for categorical in categorical_sequence:
            token_sequence.append(index[np.argmax(categorical)])
 
        token_sequences.append(token_sequence)
 
    return token_sequences


import pickle
import configparser

# INDEXED TAG OF TRAINED CORPUS
def get_POS_TAGS_index():
    # Load the pickle file
    # with open("models/tagindex_model.pkl", "rb") as f:
    #     tagindex_model = pickle.load(f)
    
    file = 'config.ini'
    config = configparser.ConfigParser()
    config.read(file)

    postagsindex_pkl_filepath = config['PATHS']['postagsindex_pkl_filepath']

    with open(postagsindex_pkl_filepath, "rb") as f:
        tagindex_model = pickle.load(f)
        
    return tagindex_model

print(get_POS_TAGS_index())


import pickle

# INDEXED TAG OF TRAINED CORPUS
def get_NER_TAGS_index():
    # Load the pickle file
    with open("models/ner_tagindex_model.pkl", "rb") as f:
        tagindex_model = pickle.load(f)
        
    return tagindex_model



import pickle
import configparser


# VOCABULARY OF THE MODEL
def get_VOCAB_model():
    # with open("models/vocab_model2.pkl", "rb") as f:
    #     vocab_model = pickle.load(f)
    
    file = 'config.ini'
    config = configparser.ConfigParser()
    config.read(file)

    vocabs_pkl_filepath = config['PATHS']['vocabs_pkl_filepath']

    with open(vocabs_pkl_filepath, "rb") as f:
        vocab_model = pickle.load(f)
    
    return vocab_model

print(get_VOCAB_model())


import pandas as pd
import configparser

# GET CORPUS
def cebuano_corpus():
    # ceb_corpus = pd.read_csv('Datasets/annotatedtestxt.csv')
    
    file = 'config.ini'
    config = configparser.ConfigParser()
    config.read(file)

    corpus_csv_filepath = config['PATHS']['corpus_csv_filepath']

    corpus_csv_filepath = pd.read_csv(corpus_csv_filepath)
    
    return corpus_csv_filepath

cebuano_corpus()


import configparser
import h5py

file = 'config.ini'
config = configparser.ConfigParser()
config.read(file)


# print(config.sections())
# print(config['PATHS'])
# print(list(config['PATHS']))


pos_h5_filepath = config['PATHS']['pos_h5_filepath']

with h5py.File(pos_h5_filepath, 'r') as f:
    model = f['model'][()]
    print(model)



import keras
import re
import string
import tensorflow
import numpy as np
from tensorflow.keras.preprocessing.sequence import pad_sequences

from keras.layers import *
from keras.models import *
from keras import backend as K

from keras_contrib.layers.crf import CRF, crf_loss, crf_viterbi_accuracy
from keras_contrib import losses

import pickle

from POS_MODEL import POS_TAGGER_MODEL, logits_to_tokens

import configparser

ceb_stopwords = [
    "ako",
    "amua",
    "ato",
    "busa",
    "ikaw",
    "ila",
    "ilang",
    "imo",
    "imong",
    "iya",
    "iyang",
    "kaayo",
    "kana",
    "kaniya",
    "kaugalingon",
    "kay",
    "kini",
    "kinsa",
    "kita",
    "lamang",
    "mahimong",
    "mga",
    "mismo",
    "nahimo",
    "nga",
    "pareho",
    "pud",
    "sila",
    "siya",
    "unsa"
]


def remove_stopwords(text):
    return " ".join([word for word in text.split() if word.lower() not in ceb_stopwords])


# Load the pickle file
# with open("models/tagindex_model.pkl", "rb") as f:
#     tagindex_model = pickle.load(f)


file = 'config.ini'
config = configparser.ConfigParser()
config.read(file)

postagsindex_pkl_filepath = config['PATHS']['postagsindex_pkl_filepath']

with open(postagsindex_pkl_filepath, "rb") as f:
    tagindex_model = pickle.load(f)



def predict_POS_model():
    test_samples = []

    test_sample = input('INPUT YOUR TEST SENTENCE: ')
    
    # decide = input('DO YOU WANT TO PREPROCESS TEXT? Y/N: ').lower()
    
    # if decide == 'Y'.lower():
        
    #     test_sample = test_sample.lower()
    
    #     test_sample = remove_stopwords(test_sample)
        
    #     test_samples.append(test_sample.split())
    
    # else:

    test_samples.append(test_sample.split())

    max_len = len(test_samples[0])

    predictions = POS_TAGGER_MODEL(test_samples)

    predix = logits_to_tokens(predictions, {i: t for t, i in tagindex_model.items()})

    # print('\n')
    # print(test_samples[0])
    # print(predix[0][:max_len])
    sentence = test_samples[0]
    tagged = predix[0][:max_len]
    return sentence, tagged

# sentz, tagz = predict_model()
# print(sentz)
# print(tagz)

test, sentz = predict_POS_model()
print(test)
print(sentz)


import keras
import re
import string
import tensorflow
import numpy as np
from tensorflow.keras.preprocessing.sequence import pad_sequences

from keras.layers import *
from keras.models import *
from keras import backend as K

from keras_contrib.layers.crf import CRF, crf_loss, crf_viterbi_accuracy
from keras_contrib import losses

import pickle


class attention(Layer):
      def __init__(self, name=None, return_sequences=True, **kwargs):
        super(attention, self).__init__(name=name, **kwargs)
        self.return_sequences = return_sequences

        super(attention,self).__init__()

      def build(self, input_shape):
        self.W=self.add_weight(name="att_weight", shape=(input_shape[-1],1),
                               initializer="normal")
        self.b=self.add_weight(name="att_bias", shape=(input_shape[1],1),
                               initializer="zeros")
        
        super(attention,self).build(input_shape)


      def call(self, x):
        e = K.tanh(K.dot(x,self.W)+self.b)
        a = K.softmax(e, axis=1)
        output = x*a
        if self.return_sequences:

            return output
        return K.sum(output, axis=1)


import keras
import re
import string
import tensorflow
import numpy as np
from tensorflow.keras.preprocessing.sequence import pad_sequences

from keras.layers import *
from keras.models import *
from keras import backend as K

from keras_contrib.layers.crf import CRF, crf_loss, crf_viterbi_accuracy
from keras_contrib import losses

import pickle

from NER_MODEL import NER_TAGGER_MODEL, logits_to_tokens



# Load the pickle file
with open("models/ner_tagindex_model.pkl", "rb") as f:
    tagindex_model = pickle.load(f)

def predict_NER_model():
    test_samples = []

    test_sample = input('INPUT YOUR TEST SENTENCE: ')
    
    test_samples.append(test_sample.split())

    max_len = len(test_samples[0])

    predictions = NER_TAGGER_MODEL(test_samples)

    predix = logits_to_tokens(predictions, {i: t for t, i in tagindex_model.items()})

    # print('\n')
    # print(test_samples[0])
    # print(predix[0][:max_len])
    sentence = test_samples[0]
    tagged = predix[0][:max_len]
    return sentence, tagged

# sentz, tagz = predict_model()
# print(sentz)
# print(tagz)


from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    
]

setup(
    name='CNLTK-Beta-version',
    version='1.0.0.1.1',
    description='Beta version of CNLTK library',
    long_description=open('README.md').read(),
    url='https://github.com/AG0nzales',
    author='Joshua Gonzales',
    author_email='jgonzales_190000001387@uic.edu.ph',
    license='MIT',
    classifiers=classifiers,
    keywords='NLP',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        '': ['*.h5','*.pkl','*.csv','config.ini'],
    },
    install_requires=['']
)